ResolvesServerCert

Trait ResolvesServerCert 

pub trait ResolvesServerCert:
    Debug
    + Send
    + Sync {
    // Required method
    fn resolve(
        &self,
        client_hello: ClientHello<'_>,
    ) -> Option<Arc<CertifiedKey>>;
}
How to choose a certificate chain and signing key for use in server authentication.

This is suitable when selecting a certificate does not require I/O or when the application is using blocking I/O anyhow.

For applications that use async I/O and need to do I/O to choose a certificate (for instance, fetching a certificate from a data store), the Acceptor interface is more suitable.

Required Methods

fn resolve(&self, client_hello: ClientHello<'_>) -> Option<Arc<CertifiedKey>>

Choose a certificate chain and matching key given simplified ClientHello information.

Return None to abort the handshake.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors